
%
% DISCLAIMER : 
% ============
% This software was developed at Physikalisch-Technische Bundesanstalt 
% (PTB). The software is made available "as is" free of cost. PTB assumes 
% no responsibility whatsoever for its use by other parties, and makes no 
% guarantees, expressed or implied, about its quality, reliability, safety,
% suitability or any other characteristic. In no event will PTB be liable 
% for any direct, indirect or consequential damage arising in connection 
% with the use of this software.
%
% Diese Software wurde in der Physikalisch-Technischen Bundesanstalt entwickelt. 
% Die Software wird unentgeldlich, wie sie ist, zur Verfuegung gestellt. Die PTB 
% uebernimmt keine Haftung, egal aus welchem Rechtsgrund, fuer die Nutzung der Software 
% durch Dritte und garantiert weder ausdruecklich noch konkludent fuer die Qualitaet, 
% Sicherheit, Zuverlaessigkeit, Tauglichkeit oder andere Merkmale der Software. 
% In keinem Fall uebernimmt die PTB die Haftung fuer direkte, indirekte Schaeden oder 
% fuer Folgeschaeden, die durch die Nutzung der Software entstehen. 
%
% This class define some options for the bandpass
%
% copyright F. Schmaehling & S. Eichstaedt (PTB) 2014

classdef BPOptions < handle
   %Bandpass (slitfunction) options - organized as a class
   
   properties
      skew = 1;      %symmetry
      noise = 0;     %noise bandpass upper level, e.g. 2e-2;
      noise_low = 0; %noise bandpass lower level, e.g. 1e-3;
   end
   
   methods
      
      %setter/getter
      function set.skew(this,skew)
         assert(~isempty(skew),'error: slitfunction (bandpass) skew, please insert a numerical between -1 and 1');
         assert((skew>=-1 && skew <=1),'error: slitfunction (bandpass) skew should between -1 and 1');
         this.skew = skew;
      end
      function skew = get.skew(this)
         skew = this.skew;
      end
      function set.noise(this,noise)
         assert(noise>=0,'error: noise upper level should be >= 0');
         this.noise = noise;
      end
      function noise = get.noise(this)
         noise = this.noise;
      end
      function set.noise_low(this,noise_low)
         assert(noise_low>=0,'error: noise lower should be >= 0');
         this.noise_low = noise_low;
      end
      function noise_low = get.noise_low(this)
         noise_low = this.noise_low;
      end
   end
   
end

