% DISCLAIMER : 
% ============
% This software was developed at Physikalisch-Technische Bundesanstalt 
% (PTB). The software is made available "as is" free of cost. PTB assumes 
% no responsibility whatsoever for its use by other parties, and makes no 
% guarantees, expressed or implied, about its quality, reliability, safety,
% suitability or any other characteristic. In no event will PTB be liable 
% for any direct, indirect or consequential damage arising in connection 
% with the use of this software.
%
% Diese Software wurde in der Physikalisch-Technischen Bundesanstalt entwickelt. 
% Die Software wird unentgeldlich, wie sie ist, zur Verfuegung gestellt. Die PTB 
% uebernimmt keine Haftung, egal aus welchem Rechtsgrund, f?r die Nutzung der Software 
% durch Dritte und garantiert weder ausdruecklich noch konkludent f?r die Qualitaet, 
% Sicherheit, Zuverlaessigkeit, Tauglichkeit oder andere Merkmale der Software. 
% In keinem Fall uebernimmt die PTB die Haftung f?r direkte, indirekte Schaeden oder 
% fuer Folgeschaeden, die durch die Nutzung der Software entstehen. 
%
%   DO3 Differential Operator 3-Point method
%   Algorithm based on 
%   Wooliams E., Spectrometer bandwidth correction for generalized bandpass functions, Metrologia 48 (2011) 164-172)
%
%   Input parameters
%   lambda      ... support of slitfunction
%	b           ... spectrometer slifunction
%	Delta       ... full base half width of the slitfunction
%	delta       ... sampledist of the measurement points
%	M           ... measured transmission curve
%
% copyright F. Schmaehling (PTB) 2012

function [Shat,a] = DO3(lambda,b,Delta,delta,M)

    M = M(:)';

% calculation of moments
    I0 = trapz(lambda-Delta,b); % for normalization of b
	I1 = trapz(lambda-Delta,(lambda-Delta).*(b/I0));
	I2 = trapz(lambda-Delta,(lambda-Delta).^2.*(b/I0));
    
% calculation of coefficients
    a3m1 = (I1^2/(delta^2)+I1/(2*delta)-I2/(2*delta^2));
    a30  = (1-2*I1^2/(delta^2)+I2/(delta^2));
    a3p1 = (I1^2/(delta^2)-I1/(2*delta)-I2/(2*delta^2));
    
    a = [a3m1,a30,a3p1];
    
	Shat = a*[M(1:end-2);M(2:end-1);M(3:end)]; 
    Shat = [0,Shat,0];

end

