
% DISCLAIMER : 
% ============
% This software was developed at Physikalisch-Technische Bundesanstalt 
% (PTB). The software is made available "as is" free of cost. PTB assumes 
% no responsibility whatsoever for its use by other parties, and makes no 
% guarantees, expressed or implied, about its quality, reliability, safety,
% suitability or any other characteristic. In no event will PTB be liable 
% for any direct, indirect or consequential damage arising in connection 
% with the use of this software.
%
% Diese Software wurde in der Physikalisch-Technischen Bundesanstalt entwickelt. 
% Die Software wird unentgeldlich, wie sie ist, zur Verfuegung gestellt. Die PTB 
% uebernimmt keine Haftung, egal aus welchem Rechtsgrund, f?r die Nutzung der Software 
% durch Dritte und garantiert weder ausdruecklich noch konkludent f?r die Qualitaet, 
% Sicherheit, Zuverlaessigkeit, Tauglichkeit oder andere Merkmale der Software. 
% In keinem Fall uebernimmt die PTB die Haftung f?r direkte, indirekte Schaeden oder 
% fuer Folgeschaeden, die durch die Nutzung der Software entstehen. 
%
%   DO5 Differential Operator 5-Point method
%   Algorithm based on 
%   Wooliams E., Spectrometer bandwidth correction for generalized bandpass functions, Metrologia 48 (2011) 164-172)
%
%   Input parameters
%   lambda      ... support of slitfunction
%	b           ... spectrometer slifunction
%	Delta       ... full base half width of the slitfunction
%	delta       ... sampledist of the measurement points
%	M           ... measured transmission curve
%
% copyright F. Schmaehling (PTB) 2012
%

function [Shat,a] = DO5(lambda,b,Delta,delta,M)

    M = M(:)';
    
% calculation of moments
	I0 = trapz(lambda-Delta,b); 
% normalisation
    b = b/I0;
	I1 = trapz(lambda-Delta,(lambda-Delta).*b);
	I2 = trapz(lambda-Delta,(lambda-Delta).^2.*b);
	I3 = trapz(lambda-Delta,(lambda-Delta).^3.*b);
	I4 = trapz(lambda-Delta,((lambda-Delta).^4).*b);
    
% calculation of coefficients    
	A0 = 1;
	A1 = -I1;
	A2 = -I2/2+I1^2;
	A3 = -I3/6+I1*I2-I1^3;
	A4 = -I4/24+I1*I3/3+(I2^2)/4-3*(I1^2)*I2/2+I1^4;
	
	a0 = A0-5*A2/(2*delta^2)+6*A4/(delta^4);
	a1m = -2*A1/(3*delta)+4*A2/(3*delta^2)+A3/(delta^3)-4*A4/(delta^4);
	a1p = +2*A1/(3*delta)+4*A2/(3*delta^2)-A3/(delta^3)-4*A4/(delta^4);
	a2m = +A1/(12*delta)-A2/(12*delta^2)-A3/(2*delta^3)+A4/(delta^4);
	a2p = -A1/(12*delta)-A2/(12*delta^2)+A3/(2*delta^3)+A4/(delta^4);
    
    a = [a2m a1m a0 a1p a2p];
% estimation    
	Shat = a*[M(1:end-4);M(2:end-3);M(3:end-2);M(4:end-1);M(5:end)];
    Shat = [0,0,Shat,0,0];

end

