
%
% DISCLAIMER : 
% ============
% This software was developed at Physikalisch-Technische Bundesanstalt 
% (PTB). The software is made available "as is" free of cost. PTB assumes 
% no responsibility whatsoever for its use by other parties, and makes no 
% guarantees, expressed or implied, about its quality, reliability, safety,
% suitability or any other characteristic. In no event will PTB be liable 
% for any direct, indirect or consequential damage arising in connection 
% with the use of this software.
%
% Diese Software wurde in der Physikalisch-Technischen Bundesanstalt entwickelt. 
% Die Software wird unentgeldlich, wie sie ist, zur Verfuegung gestellt. Die PTB 
% uebernimmt keine Haftung, egal aus welchem Rechtsgrund, fuer die Nutzung der Software 
% durch Dritte und garantiert weder ausdruecklich noch konkludent fuer die Qualitaet, 
% Sicherheit, Zuverlaessigkeit, Tauglichkeit oder andere Merkmale der Software. 
% In keinem Fall uebernimmt die PTB die Haftung fuer direkte, indirekte Schaeden oder 
% fuer Folgeschaeden, die durch die Nutzung der Software entstehen.
%
% Tikhonov Regularization technique are descibed in
%    G van Kempen, Image Restoration in Flourescence Microscopy, PhD Thesis, Technische
%    Universiteit Delft, Holland, 1999
%    J. B. de Monvel, E. Scarfone, S. Le Calvez and M. Ulfendahl. Image restoration for 
%    confocal microscopy: Improving the limits of deconvolution, with application to the 
%    visualization of the mammalian hearing organ. Biophysical Journal, 80:2455-2470, 2001
%
% copyright F. Schmaehling & S. Eichstaedt (PTB) 2014

function [regularization] = Regularization_Tikhonov(new,old,varargin)
   assert(~isempty(new),'signal that should be regularized has no elements');
   assert(~isempty(old),'signal that should be regularized has no elements');
   
   if nargin>1
      if (isempty(varargin{1}))
         varargin{1} = 1;
      end
      assert(varargin{1}>0,'spacing should be larger than 0');
      delta = varargin{1};
      if nargin>2
          if (isempty(varargin{2}))
              varargin{2} = 5e-4;
          end
          assert(varargin{2}>0,'regularization parameters must be larger than 0');
          tau = varargin{2};
      else
          tau = 5e-4;
      end
   else
      delta = 1;
      tau = 5e-4;
   end
   
   
   laplace = gradient(gradient(old,delta),delta);
   regularization = (1./(1-2.*tau.*laplace.*old));
end

