%
% DISCLAIMER : 
% ============
% This software was developed at Physikalisch-Technische Bundesanstalt 
% (PTB). The software is made available "as is" free of cost. PTB assumes 
% no responsibility whatsoever for its use by other parties, and makes no 
% guarantees, expressed or implied, about its quality, reliability, safety,
% suitability or any other characteristic. In no event will PTB be liable 
% for any direct, indirect or consequential damage arising in connection 
% with the use of this software.
%
% Diese Software wurde in der Physikalisch-Technischen Bundesanstalt entwickelt. 
% Die Software wird unentgeldlich, wie sie ist, zur Verfuegung gestellt. Die PTB 
% uebernimmt keine Haftung, egal aus welchem Rechtsgrund, fuer die Nutzung der Software 
% durch Dritte und garantiert weder ausdruecklich noch konkludent fuer die Qualitaet, 
% Sicherheit, Zuverlaessigkeit, Tauglichkeit oder andere Merkmale der Software. 
% In keinem Fall uebernimmt die PTB die Haftung fuer direkte, indirekte Schaeden oder 
% fuer Folgeschaeden, die durch die Nutzung der Software entstehen. 
%
% An example for the usage of the "new" object orientated software approach for
% the Richardsdon-Lucy deconvolution can be found in example_1.m
%
% In regard to the new software design (released end of march 2014) this
% function is a wrapper to make statements using the old software design
% runable in further designs
% 
% usage: [Shat,RMS,curv,tau] = RichLucy(b,delta,M) 
% 
% Input parameters
% b           ... spectrometer bandpass function
% delta       ... sampledist of the measurement points
% M           ... measured spectral amplitude 
% 
% optional parameters
% max_iter    ... maximum number of RichLucy iterations (default = 200)
% min_iter    ... minimum number of RichLucy iterations (default = 1)
% threshold   ... relative threshold to determine wavelength interval with relevant M values (default = 1e-3)
% verbose     ... flag (0 or 1) for textual output (default = 1)
% 
% 
% copyright F. Schmaehling & S. Eichstaedt (PTB) 2014
%


function [Shat,RMS,curv,tau] = RichLucy(b,delta,M,varargin)
% wrapper function for the new RichLucy_OOP 
%(mimic the old not oop-approach call RichLucy())

   %make sure that the dimension is correct
   b = b(:)';
   
   if (nargin < 3)
		Shat = [];
		fprintf(2,'Not enough input parameters.\n');
		return;
   end
   
   %set default values
   max_iter = 200;
   min_iter = 1;
   threshold = 1e-3; %comply with all elements
   verbose = 1;
    
   % overwrite defaults with user-supplied input
   if nargin >= 4
      if ~isempty(varargin{1})
         max_iter = varargin{1};
      end
      if nargin >= 5
         if ~isempty(varargin{2})
            min_iter = varargin{2};
         end
         if nargin >= 6
            if (~isempty(varargin{3}))
               threshold = varargin{3};
            end
            if nargin >= 7
               verbose = varargin{4};
               if nargin == 8
                  fignr = varargin{5};
               end
            end
         end
      end
   end

   %---   
   clear my_RLO;
   %create an RichLucyOptions object
   my_RLO = RichLucyOptions;
   my_RLO.max_iter = max_iter;
   my_RLO.min_iter = min_iter;
   my_RLO.threshold = threshold;
   my_RLO.verbose = verbose;
   
   clear my_RichLucy;
   %create an RichLucy_OOp object
   if (mod(numel(b),2)==0)
      bandwidth = (numel(b)-1)/2*delta;
   else
      bandwidth = (numel(b)-1)/2*delta;
   end
   my_RichLucy = RichLucy_OOP(100:delta:100+delta*(numel(M)-1),M,[],bandwidth,delta,b,[],[],my_RLO);
   %to start RichLucy deconvolution -> call method Start_RL of the RichLucy_OOP object
   Shat = my_RichLucy.Start_RL;
   
   RMS = [];
   curv = [];
   tau = [];
   
end

