
%
% DISCLAIMER : 
% ============
% This software was developed at Physikalisch-Technische Bundesanstalt 
% (PTB). The software is made available "as is" free of cost. PTB assumes 
% no responsibility whatsoever for its use by other parties, and makes no 
% guarantees, expressed or implied, about its quality, reliability, safety,
% suitability or any other characteristic. In no event will PTB be liable 
% for any direct, indirect or consequential damage arising in connection 
% with the use of this software.
%
% Diese Software wurde in der Physikalisch-Technischen Bundesanstalt entwickelt. 
% Die Software wird unentgeldlich, wie sie ist, zur Verfuegung gestellt. Die PTB 
% uebernimmt keine Haftung, egal aus welchem Rechtsgrund, fuer die Nutzung der Software 
% durch Dritte und garantiert weder ausdruecklich noch konkludent fuer die Qualitaet, 
% Sicherheit, Zuverlaessigkeit, Tauglichkeit oder andere Merkmale der Software. 
% In keinem Fall uebernimmt die PTB die Haftung fuer direkte, indirekte Schaeden oder 
% fuer Folgeschaeden, die durch die Nutzung der Software entstehen. 
%
% The proposed stopping rule for the Richardson-Lucy approach is described in detail in the
% MST journal
%    "Baysian deconvolution method applied to experimental bidirectional transmittance distribution functions"
%    Audenaert, Leloup, Durinck, Deconinck and Hanselaer; MST 2013
%
% copyright F. Schmaehling & S. Eichstaedt (PTB) 2014

function [im] =  StoppingRule_EEM_Crit(course,M,min_iter,max_iter,BP,verbose)

   M = M(:)';
   bd = BP.b*BP.delta;
   bdtilde = fliplr(bd);
   E = zeros(size(course,1),1);
   for k = 1:size(course,1)
      tmp = conv(course(k,:),bdtilde,'same');
      E(k,1) = sqrt(sum(((tmp-M)./tmp).^2)/length(M));
   end
   zerop = extr(E); %find all locate extremas
   qm = find(zerop{2}==1);
   im = qm(end); %last local minima
   if isempty(qm)
      if verbose
         fprintf(2,'Calculation of optimal stopping value failed.\nTaking tau=1e-4 as fallback.\n');
      end
      tau = 1e-3;
   else      
      tau = E(im);  
   end
   if verbose == 2
      %plot of the curvature-criterium
      figure(numel(get(0,'Children'))+1);clf;
      plot(1:numel(E),E,'-b');
      hold on;
      line([im, im],[min(E), max(E)],'color','red');
      xlabel('iter nr.');
      ylabel('value of the error function E(k)');
   end
   if verbose
      fprintf('computed optimal number of iterations: %d\n',im-1);
   end
   
end

