
% DISCLAIMER : 
% ============
% This software was developed at Physikalisch-Technische Bundesanstalt 
% (PTB). The software is made available "as is" free of cost. PTB assumes 
% no responsibility whatsoever for its use by other parties, and makes no 
% guarantees, expressed or implied, about its quality, reliability, safety,
% suitability or any other characteristic. In no event will PTB be liable 
% for any direct, indirect or consequential damage arising in connection 
% with the use of this software.
%
%
%   Input parameters
%   bandwidth			... bandwidth (half width of the bandpass)
%	sampledist          ... sampledist bandpass
%	skew				... Value between 0 and 2 (How skew is the bandpass?)
%	noise				... noise (noise at the border (relative))
%	noise_low           ... noise_low (noise at the peak (relative))
%
% copyright S. Eichstaedt (PTB) 2012

function [hat,lambda,u_hat] = simulate_bandpass(bandwidth,sampledist,skew,noise,noise_low)
	
% definition of x-axis
	lambda = 0:sampledist:2*bandwidth;
	ind_kl = find(lambda < skew*bandwidth); % indices for increasing slope
	ind_gr = find(lambda >= skew*bandwidth);% indices for decreasing slope
    
% definition of bandpass function    
	hat = zeros(size(lambda));
    hat(ind_kl) = lambda(ind_kl)/(skew*bandwidth^2);
    hat(ind_gr) = -lambda(ind_gr)/( (2-skew)*bandwidth^2 ) + 2/( (2-skew)*bandwidth );

% definition of noise/measurement uncertainty
    noiseslit = zeros(size(lambda));
    noiseslit(ind_kl) = -((noise-noise_low)/(skew*bandwidth))*lambda(ind_kl) + noise;
    noiseslit(ind_gr) = ((noise-noise_low)/((2-skew)*bandwidth))*lambda(ind_gr) + (noise - 2*(noise-noise_low)/(2-skew));
    u_hat = hat.*noiseslit;
	epsilon = randn(size(lambda)).*u_hat;
    hat = epsilon.*u_hat+hat;

end
