% DISCLAIMER : 
% ============
% This software was developed at Physikalisch-Technische Bundesanstalt 
% (PTB). The software is made available "as is" free of cost. PTB assumes 
% no responsibility whatsoever for its use by other parties, and makes no 
% guarantees, expressed or implied, about its quality, reliability, safety,
% suitability or any other characteristic. In no event will PTB be liable 
% for any direct, indirect or consequential damage arising in connection 
% with the use of this software.
%
%
% This function simulates the measurement as a integral of the input spectrum weighted with the bandpass function. 
%
% Input parameters
%
%   Sfun..........function handle to evaluate S(lambda) for arbitrary wavelengths
%   lambda........vector of wavelength at wich is measured
%   bandwidth.....the FWHM/bandwidth value of the bandpass function
%   delta_b.......wavelength step size in bandpass measurement
%   noise_low.....lower limit for measurement noise
%   noise_up......upper limit for measurement noise
%
% copyright F Schmaehling (PTB) 2012

function [M,uncM,M_clean] = simulate_measurement(Sfun,lambda,b,bandwidth,delta_b,noise_low,noise_up)

% simulation of the measurement
    M = zeros(size(lambda));
    for ii = 1:length(lambda)
        lambda_int = lambda(ii)-bandwidth:delta_b:lambda(ii)+bandwidth;
        M(ii) = trapz(lambda_int,Sfun(lambda_int).*b);
    end    
   % add measurement noise
     uncM = (-(noise_up-noise_low)*( M/max(M) ) + noise_up).*M;    
     M_clean = M;
     M    = M + randn(size(M)).*uncM;      
end
